@@ -48,7 +48,7 @@ class WinrsCmd(cmd.Cmd):
     @defer.inlineCallbacks
     def _exit(self):
         yield self._shell.delete()
-        reactor.stop()
+        app.stop_reactor()
 
     def postloop(self):
         print
@@ -57,8 +57,7 @@ class WinrsCmd(cmd.Cmd):
 @defer.inlineCallbacks
 def long_running_main(args):
     try:
-        client = create_long_running_command(
-            args.remote, args.authentication, args.username, args.password)
+        client = create_long_running_command(args.conn_info)
         yield client.start(args.command)
         for i in xrange(5):
             stdout, stderr = yield task.deferLater(
@@ -66,14 +65,12 @@ def long_running_main(args):
             print_output(stdout, stderr)
         yield client.stop()
     finally:
-        reactor.stop()
+        app.stop_reactor()
 
 
 @defer.inlineCallbacks
 def interactive_main(args):
-    remote = args.remote
-    shell = create_remote_shell(
-        remote, args.authentication, args.username, args.password)
+    shell = create_remote_shell(args.conn_info)
     response = yield shell.create()
     intro = '\n'.join(response.stdout)
     winrs_cmd = WinrsCmd(shell)
@@ -82,66 +79,71 @@ def interactive_main(args):
 
 @defer.inlineCallbacks
 def batch_main(args):
-    remote = args.remote
+    hostname = args.conn_info.hostname
     command = args.command
     try:
-        shell = create_remote_shell(
-            remote, args.authentication, args.username, args.password)
-        print 'Creating shell on {0}.'.format(remote)
+        shell = create_remote_shell(args.conn_info)
+        print 'Creating shell on {0}.'.format(hostname)
         yield shell.create()
         for i in range(10):
-            print '\nSending to {0}:\n  {1}'.format(remote, command)
+            print '\nSending to {0}:\n  {1}'.format(hostname, command)
             response = yield shell.run_command(command)
-            print '\nReceived from {0}:'.format(remote)
+            print '\nReceived from {0}:'.format(hostname)
             print_output(response.stdout, response.stderr)
         response = yield shell.delete()
-        print "\nDeleted shell on {0}.".format(remote)
+        print "\nDeleted shell on {0}.".format(hostname)
         print_output(response.stdout, response.stderr)
         print "\nExit code of shell on {0}: {1}".format(
-            remote, response.exit_code)
+            hostname, response.exit_code)
     finally:
-        if reactor.running:
-            reactor.stop()
+        app.stop_reactor()
 
 
 @defer.inlineCallbacks
 def single_shot_main(args):
     try:
-        client = create_single_shot_command(
-            args.remote, args.authentication, args.username, args.password)
+        client = create_single_shot_command(args.conn_info)
         results = yield client.run_command(args.command)
         pprint(results)
     finally:
-        reactor.stop()
+        app.stop_reactor()
 
 
-def tx_main(args, config):
-    if args.kind == "long":
-        long_running_main(args)
-    elif args.kind == "single":
-        single_shot_main(args)
-    elif args.kind == "batch":
-        batch_main(args)
-    else:
-        interactive_main(args)
+class WinrsUtility(object):
 
+    def tx_main(self, args, config):
+        if args.kind == "long":
+            long_running_main(args)
+        elif args.kind == "single":
+            single_shot_main(args)
+        elif args.kind == "batch":
+            batch_main(args)
+        else:
+            interactive_main(args)
 
-def add_args(parser):
-    parser.add_argument(
-        "kind", nargs='?', default="interactive",
-        choices=["interactive", "single", "batch", "long"])
-    parser.add_argument("--command", "-x")
+    def add_args(self, parser):
+        parser.add_argument(
+            "kind", nargs='?', default="interactive",
+            choices=["interactive", "single", "batch", "long"])
+        parser.add_argument("--command", "-x")
 
+    def check_args(self, args):
+        if not args.command and args.kind in ["single", "batch", "long"]:
+            print >>sys.stderr, \
+                "ERROR: {0} requires that you specify a command."
+            return False
+        elif args.config:
+            print >>sys.stderr, \
+                "ERROR: The winrs command does not support a configuration " \
+                "file at this time."
+            return False
+        return True
 
-def check_args(args):
-    if not args.command and args.kind in ["single", "batch", "long"]:
-        print >>sys.stderr, "ERROR: {0} requires that you specify a command."
-        return False
-    elif args.config:
-        print >>sys.stderr, "ERROR: The winrs command does not support " \
-                            "a configuration file at this time."
-        return False
-    return True
+    def add_config(self, parser, config):
+        pass
+
+    def adapt_args_to_config(self, args, config):
+        pass
 
 if __name__ == '__main__':
-    app.main(tx_main, add_args, check_args)
+    app.main(WinrsUtility())
